      SUBROUTINE SETTYP (KARRAY, LPTR, IVALUE)
C-----------------------------------------------------------------------
C! replaces the symbol type code in the data description structure
C# POPS-lang
C-----------------------------------------------------------------------
C;  Copyright (C) 1995
C;  Associated Universities, Inc. Washington DC, USA.
C;
C;  This program is free software; you can redistribute it and/or
C;  modify it under the terms of the GNU General Public License as
C;  published by the Free Software Foundation; either version 2 of
C;  the License, or (at your option) any later version.
C;
C;  This program is distributed in the hope that it will be useful,
C;  but WITHOUT ANY WARRANTY; without even the implied warranty of
C;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C;  GNU General Public License for more details.
C;
C;  You should have received a copy of the GNU General Public
C;  License along with this program; if not, write to the Free
C;  Software Foundation, Inc., 675 Massachusetts Ave, Cambridge,
C;  MA 02139, USA.
C;
C;  Correspondence concerning AIPS should be addressed as follows:
C;         Internet email: aipsmail@nrao.edu.
C;         Postal address: AIPS Project Office
C;                         National Radio Astronomy Observatory
C;                         520 Edgemont Road
C;                         Charlottesville, VA 22903-2475 USA
C-----------------------------------------------------------------------
C-----------------------------------------------------------------------
C   SETTYP sets the type code for either a symbol or literal as defined
C   by the location LPTR, and the new type code IVALUE.
C   Inputs:
C      LPTR    I           location + 1 in KARRAY to set new type
C      IVALUE  I           new type
C   In/Outputs:
C      KARRAY  I(>LPTR-1)  POPS array
C-----------------------------------------------------------------------
      INTEGER   KARRAY(*), LPTR, IVALUE
C-----------------------------------------------------------------------
      KARRAY(LPTR-1) = (KARRAY(LPTR-1)/16)*16 + IVALUE
C
 999  RETURN
      END
